@@ -12,7 +12,9 @@ class StartStopProfiler:
             self.running = True
         else:
             self.profiler.stop()
+            self.running = False
             self.profiler.open_in_browser()
+            self.profiler.reset()
 
 
 t = StartStopProfiler()
